@@ -6,7 +6,7 @@ namespace Icinga\Module\Icingadb\Model;
 
 use ipl\Orm\Behavior\Binary;
 use ipl\Orm\Behaviors;
-use ipl\Orm\Model;
+use Icinga\Module\Icingadb\Common\Model;
 use ipl\Orm\Relations;
 
 /**
